@@ -48,7 +48,7 @@ class AccessLogMiddleware(BaseHTTPMiddleware):
   async def dispatch(self, request, call_next):
     response = await call_next(request)
     if response.status_code < 400:
-      path = urlparse(request.url).path
+      path = urlparse(str(request.url)).path
       logging.info(f'[{response.status_code}] {request.method} {path}')
     return response
 
@@ -86,7 +86,7 @@ class GatewayServer(threading.Thread):
 
   async def http_exception(self, request, exc):
     if 'favicon.ico' not in str(request.url):
-      path = urlparse(request.url).path
+      path = urlparse(str(request.url)).path
       logging.error(f'[{exc.status_code}] {request.method} {path} - {exc.detail}')
     return JSONResponse({'detail': exc.detail, 'status': exc.status_code}, status_code=exc.status_code)
 
